@@ -60,6 +60,12 @@ class PersistedRmq(object):
         else:
             return await self.conn.hget(f'fail:{self.channel}', self.client_id)
 
+    async def chn_hash_get(self, chn, client_id=None):
+        if client_id:
+            return await self.conn.hget(f'fail:{chn}', client_id)
+        else:
+            return await self.conn.hget(f'fail:{chn}', self.client_id)
+
     async def hash_set(self, value):
         return await self.conn.hset(f'fail:{self.channel}', self.client_id, value)
 
@@ -69,6 +75,9 @@ class PersistedRmq(object):
     async def hash_keys(self):
         return await self.conn.hkeys(f'fail:{self.channel}')
 
+    async def chn_hash_keys(self, chn):
+        return await self.conn.hkeys(f'fail:{chn}')
+
     async def duplicate(self) -> bool:
         ts = await self.get('client-map', self.lock_key)
         logging.error(f'key:{self.lock_key} duplicate:{ts} vs {self.timestamp} {int(ts) != self.timestamp}')
@@ -122,15 +131,30 @@ class PersistedRmq(object):
                     await self.close()
                     return
 
-    async def publish(self, message):
-        await self.conn.publish(self.subscribe_chn, message)
-        logging.error(f'published to {self.subscribe_chn}!')
-        keys = await self.hash_keys()
-        logging.error(f'keys:{keys}')
+    async def publish(self, message, another_chn=None):
+        keys = []
+        if another_chn:
+            cb_chn = f'chn:{self.another_chn}'
+            await self.conn.publish(cb_chn, message)
+            logging.error(f'published to {another_chn}!')
+            keys = await self.chn_hash_keys(another_chn)
+            for key in keys:
+                queue_key = await self.chn_hash_get(another_chn, client_id=key)
+                logging.error(f'pub queue:{queue_key}')
+                if queue_key:
+                    keys.append(queue_key)
+        else:    
+            await self.conn.publish(self.subscribe_chn, message)
+            logging.error(f'published to {self.subscribe_chn}!')
+            keys = await self.hash_keys()
+            logging.error(f'keys:{keys}')
+            for key in keys:
+                queue_key = await self.hash_get(client_id=key)
+                logging.error(f'pub queue:{queue_key}')
+                if queue_key:
+                   keys.append(queue_key)
         for key in keys:
-            queue_key = await self.hash_get(client_id=key)
-            logging.error(f'pub queue:{queue_key}')
-            if queue_key:
-                await self.conn.rpush(queue_key, message)
-                logging.error(f'往失败队列节点{key}push')
+            await self.conn.rpush(queue_key, message)
+            logging.error(f'往失败队列节点{key}push')
+
 
